==> yubikey-manager_0.7.1.orig.tar.gz: yubikey-manager-0.7.1/ykman/settings.py <==
# Copyright (c) 2017 Yubico AB
# All rights reserved.
#
#   Redistribution and use in source and binary forms, with or
#   without modification, are permitted provided that the following
#   conditions are met:
#
#    1. Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#    2. Redistributions in binary form must reproduce the above
#       copyright notice, this list of conditions and the following
#       disclaimer in the documentation and/or other materials provided
#       with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

from __future__ import absolute_import

import os
import json


DIR_NAME = '.ykman'


def _get_conf_dir():
    if os.path.isdir(DIR_NAME):
        return os.path.abspath(DIR_NAME)
    return os.path.join(os.path.expanduser('~'), DIR_NAME)


class Settings(dict):
    def __init__(self, name):
        self.fname = os.path.join(_get_conf_dir(), name + '.json')
        if os.path.isfile(self.fname):
            with open(self.fname, 'r') as f:
                self.update(json.load(f))

    def write(self):
        conf_dir = os.path.dirname(self.fname)
        if not os.path.isdir(conf_dir):
            os.makedirs(conf_dir)
        data = json.dumps(self, indent=2)
        with open(self.fname, 'w') as f:
            f.write(data)

==> yubikey-manager-4.0.0.tar.gz: yubikey-manager-4.0.0/ykman/settings.py <==
# Copyright (c) 2017 Yubico AB
# All rights reserved.
#
#   Redistribution and use in source and binary forms, with or
#   without modification, are permitted provided that the following
#   conditions are met:
#
#    1. Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#    2. Redistributions in binary form must reproduce the above
#       copyright notice, this list of conditions and the following
#       disclaimer in the documentation and/or other materials provided
#       with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

import os
import json


DIR_NAME = ".ykman"


def _get_conf_dir():
    # Note, this is currently experimental and unsupported.
    # This behavior may be changed at any time.
    if "YKMAN_XDG_EXPERIMENTAL" in os.environ:
        # Use XDG base directory structure.
        xdg_data_default = os.path.join(os.path.expanduser("~"), ".local", "share")
        xdg_data_home = os.environ.get("XDG_DATA_HOME", xdg_data_default)
        return os.path.join(xdg_data_home, "ykman")

    return os.path.join(os.path.expanduser("~"), DIR_NAME)


class Settings(dict):
    def __init__(self, name):
        self.fname = os.path.join(_get_conf_dir(), name + ".json")
        if os.path.isfile(self.fname):
            with open(self.fname, "r") as f:
                self.update(json.load(f))

    def __eq__(self, other):
        return other is not None and self.fname == other.fname

    def __ne__(self, other):
        return other is not None or self.fname != other.fname

    def write(self):
        conf_dir = os.path.dirname(self.fname)
        if not os.path.isdir(conf_dir):
            os.makedirs(conf_dir)
        data = json.dumps(self, indent=2)
        with open(self.fname, "w") as f:
            f.write(data)

    __hash__ = None
